==> checker-framework-3.52.1.zip: annotated-jdk/src/java.base/share/classes/sun/security/x509/GeneralSubtrees.java <==
/*
 * Copyright (c) 1997, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.x509;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.*;
import java.util.*;
import sun.security.util.*;

public class GeneralSubtrees implements Cloneable {

    public GeneralSubtrees() {
    }

    public GeneralSubtrees(DerValue val) throws IOException {
    }

    public GeneralSubtree get(int index);

    public void remove(int index);

    public void add(GeneralSubtree tree);

    @Pure
    public boolean contains(GeneralSubtree tree);

    public int size();

    public Iterator<GeneralSubtree> iterator();

    public List<GeneralSubtree> trees();

    public Object clone();

    public String toString();

    public void encode(DerOutputStream out) throws IOException;

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object obj);

    public int hashCode();

    public GeneralSubtrees intersect(GeneralSubtrees other);

    public void union(GeneralSubtrees other);

    public void reduce(GeneralSubtrees excluded);
}

==> checker-framework-3.54.0.zip: annotated-jdk/src/java.base/share/classes/sun/security/x509/GeneralSubtrees.java <==
/*
 * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.x509;

import org.checkerframework.checker.nullness.qual.EnsuresNonNullIf;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import java.io.*;
import java.util.*;
import sun.security.util.*;

public class GeneralSubtrees implements Cloneable, DerEncoder {

    public GeneralSubtrees() {
    }

    public GeneralSubtrees(DerValue val) throws IOException {
    }

    public GeneralSubtree get(int index);

    public void remove(int index);

    public void add(GeneralSubtree tree);

    @Pure
    public boolean contains(GeneralSubtree tree);

    public int size();

    public Iterator<GeneralSubtree> iterator();

    public List<GeneralSubtree> trees();

    public Object clone();

    public String toString();

    @Override
    public void encode(DerOutputStream out);

    @Pure
    @EnsuresNonNullIf(expression = "#1", result = true)
    public boolean equals(@Nullable Object obj);

    public int hashCode();

    public GeneralSubtrees intersect(GeneralSubtrees other);

    public void union(GeneralSubtrees other);

    public void reduce(GeneralSubtrees excluded);
}
